@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -36,8 +36,6 @@
 #include <PimCommonAkonadi/ImapResourceCapabilitiesManager>
 
 #include <KColorScheme>
-#include <KComboBox>
-#include <QDialog>
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -82,7 +80,7 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
                            || Kernel::folderIsInbox(collection);
 
     mIsResourceFolder = (collection.parentCollection() == Akonadi::Collection::root());
-    QLabel *label;
+    QLabel *label = nullptr;
 
     QVBoxLayout *topLayout = new QVBoxLayout(this);
 
@@ -315,7 +313,7 @@ void CollectionGeneralPage::save(Collection &collection)
     if (mIncidencesForComboBox && mIncidencesForComboBox->isEnabled()) {
         annotations[ PimCommon::CollectionTypeUtil::kolabIncidencesFor() ]
             = collectionUtil.incidencesForToString(
-            static_cast<PimCommon::CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->currentIndex())).toLatin1();
+                  static_cast<PimCommon::CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->currentIndex())).toLatin1();
     }
 
     if (mContentsComboBox) {
@@ -386,7 +384,7 @@ void CollectionGeneralPage::slotNameChanged(const QString &name)
     if (name.startsWith(QLatin1Char('.'))
         || name.endsWith(QLatin1Char('.'))
         || name.contains(QLatin1Char('/'))
-        || name.isEmpty()) {
+        || name.trimmed().isEmpty()) {
         if (mColorName.isEmpty()) {
             const KColorScheme::BackgroundRole bgColorScheme(KColorScheme::NegativeBackground);
             KStatefulBrush bgBrush(KColorScheme::View, bgColorScheme);
