@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -28,12 +28,10 @@
 FilterActionAddToAddressBookTest::FilterActionAddToAddressBookTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 FilterActionAddToAddressBookTest::~FilterActionAddToAddressBookTest()
 {
-
 }
 
 void FilterActionAddToAddressBookTest::shouldHaveDefaultValue()
@@ -65,7 +63,7 @@ void FilterActionAddToAddressBookTest::shouldReportErrorWhenArgumentIsEmpty()
     item.setPayload<KMime::Message::Ptr>(msgPtr);
     MailCommon::ItemContext context(item, false);
 
-    filter.argsFromString("");
+    filter.argsFromString(QString());
     QVERIFY(filter.isEmpty());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::ErrorButGoOn);
     QCOMPARE(context.needsPayloadStore(), false);
@@ -81,7 +79,7 @@ void FilterActionAddToAddressBookTest::shouldReportErrorWhenCollectionIsInvalid(
     item.setPayload<KMime::Message::Ptr>(msgPtr);
     MailCommon::ItemContext context(item, false);
 
-    filter.argsFromString("foo\t-1\tddd");
+    filter.argsFromString(QStringLiteral("foo\t-1\tddd"));
     QVERIFY(filter.isEmpty());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::ErrorButGoOn);
     QCOMPARE(context.needsPayloadStore(), false);
