@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,8 +31,7 @@
 
 using namespace MailCommon;
 
-FilterActionMissingTransportDialog::FilterActionMissingTransportDialog(const QString &filtername,
-        QWidget *parent)
+FilterActionMissingTransportDialog::FilterActionMissingTransportDialog(const QString &filtername, QWidget *parent)
     : QDialog(parent)
 {
     setModal(true);
@@ -85,4 +84,3 @@ int FilterActionMissingTransportDialog::selectedTransport() const
 {
     return mComboBoxTransport->currentTransportId();
 }
-
