@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +21,12 @@ using namespace MailCommon;
 
 InvalidFilterInfo::InvalidFilterInfo()
 {
-
 }
 
 InvalidFilterInfo::InvalidFilterInfo(const QString &name, const QString &information)
-    : mName(name),
-      mInformation(information)
+    : mName(name)
+    , mInformation(information)
 {
-
 }
 
 QString InvalidFilterInfo::information() const
@@ -54,4 +53,3 @@ bool InvalidFilterInfo::operator ==(const InvalidFilterInfo &other) const
 {
     return (mName == other.name()) && (mInformation == other.information());
 }
-
