@@ -32,8 +32,6 @@ using MailCommon::FilterLog;
 
 #include <KMime/KMimeMessage>
 
-#include <KEmailAddress>
-
 #include <KConfigGroup>
 #include <KLocalizedString>
 
@@ -177,9 +175,9 @@ void SearchPattern::importLegacyConfig(const KConfigGroup &config)
 {
     SearchRule::Ptr rule
         = SearchRule::createInstance(
-        config.readEntry("fieldA").toLatin1(),
-        config.readEntry("funcA").toLatin1().constData(),
-        config.readEntry("contentsA"));
+              config.readEntry("fieldA").toLatin1(),
+              config.readEntry("funcA").toLatin1().constData(),
+              config.readEntry("contentsA"));
 
     if (rule->isEmpty()) {
         // if the first rule is invalid,
@@ -195,9 +193,9 @@ void SearchPattern::importLegacyConfig(const KConfigGroup &config)
 
     rule
         = SearchRule::createInstance(
-        config.readEntry("fieldB").toLatin1(),
-        config.readEntry("funcB").toLatin1().constData(),
-        config.readEntry("contentsB"));
+              config.readEntry("fieldB").toLatin1(),
+              config.readEntry("funcB").toLatin1().constData(),
+              config.readEntry("contentsB"));
 
     if (rule->isEmpty()) {
         return;
@@ -393,7 +391,7 @@ QDataStream &SearchPattern::operator<<(QDataStream &s)
     return s;
 }
 
-void SearchPattern::generateSieveScript(QStringList &requires, QString &code)
+void SearchPattern::generateSieveScript(QStringList &requiresModules, QString &code)
 {
     code += QLatin1String("\n#") + mName + QLatin1Char('\n');
     switch (mOperator) {
@@ -415,7 +413,7 @@ void SearchPattern::generateSieveScript(QStringList &requires, QString &code)
         if (i != 0) {
             code += QLatin1String("\n, ");
         }
-        (*it)->generateSieveScript(requires, code);
+        (*it)->generateSieveScript(requiresModules, code);
     }
 }
 
