@@ -24,7 +24,6 @@
 #include "snippetsmodel.h"
 #include "snippetvariabledialog.h"
 #include <KSharedConfig>
-#include <QAction>
 #include <KActionCollection>
 
 #include <KLocalizedString>
@@ -87,23 +86,23 @@ public:
     void load();
     void save();
 
-    SnippetsManager *q;
-    SnippetsModel *mModel;
-    QItemSelectionModel *mSelectionModel;
-    KActionCollection *mActionCollection;
-    QObject *mEditor;
+    SnippetsManager *q = nullptr;
+    SnippetsModel *mModel = nullptr;
+    QItemSelectionModel *mSelectionModel = nullptr;
+    KActionCollection *mActionCollection = nullptr;
+    QObject *mEditor = nullptr;
     QByteArray mEditorInsertMethod;
     QMap<QString, QString> mSavedVariables;
 
-    QAction *mAddSnippetAction;
-    QAction *mEditSnippetAction;
-    QAction *mDeleteSnippetAction;
-    QAction *mAddSnippetGroupAction;
-    QAction *mEditSnippetGroupAction;
-    QAction *mDeleteSnippetGroupAction;
-    QAction *mInsertSnippetAction;
-    QWidget *mParent;
-    bool mDirty;
+    QAction *mAddSnippetAction = nullptr;
+    QAction *mEditSnippetAction = nullptr;
+    QAction *mDeleteSnippetAction = nullptr;
+    QAction *mAddSnippetGroupAction = nullptr;
+    QAction *mEditSnippetGroupAction = nullptr;
+    QAction *mDeleteSnippetGroupAction = nullptr;
+    QAction *mInsertSnippetAction = nullptr;
+    QWidget *mParent = nullptr;
+    bool mDirty = false;
 };
 
 QModelIndex SnippetsManager::Private::currentGroupIndex() const
@@ -399,7 +398,10 @@ void SnippetsManager::Private::updateActionCollection(const QString &oldName, co
         const QString normalizedName = QString(actionName).replace(QLatin1Char(' '), QLatin1Char('_'));
 
         QAction *action
-            = mActionCollection->addAction(normalizedName, q, SLOT(insertActionSnippet()));
+            = mActionCollection->addAction(normalizedName, q);
+        connect(action, &QAction::triggered, q, [this]() {
+            insertActionSnippet();
+        });
         action->setProperty("snippetText", text);
         action->setText(actionName);
         mActionCollection->setDefaultShortcut(action, keySequence);
@@ -555,13 +557,19 @@ void SnippetsManager::Private::save()
             const QModelIndex index = mModel->index(j, 0, groupIndex);
 
             const QString snippetName = index.data(SnippetsModel::NameRole).toString();
-            const QString snippetText = index.data(SnippetsModel::TextRole).toString();
-            const QString snippetKeySequence = index.data(SnippetsModel::KeySequenceRole).toString();
+            if (!snippetName.isEmpty()) {
+                const QString snippetText = index.data(SnippetsModel::TextRole).toString();
+                const QString snippetKeySequence = index.data(SnippetsModel::KeySequenceRole).toString();
 
-            group.writeEntry(QStringLiteral("snippetName_%1").arg(j), snippetName);
-            group.writeEntry(QStringLiteral("snippetText_%1").arg(j), snippetText);
-            group.writeEntry(QStringLiteral("snippetKeySequence_%1").arg(j),
-                             snippetKeySequence);
+                group.writeEntry(QStringLiteral("snippetName_%1").arg(j), snippetName);
+                if (!snippetText.isEmpty()) {
+                    group.writeEntry(QStringLiteral("snippetText_%1").arg(j), snippetText);
+                }
+                if (!snippetKeySequence.isEmpty()) {
+                    group.writeEntry(QStringLiteral("snippetKeySequence_%1").arg(j),
+                                     snippetKeySequence);
+                }
+            }
         }
     }
 
@@ -607,20 +615,40 @@ SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *p
 
     d->mInsertSnippetAction = new QAction(i18n("Insert Snippet"), this);
 
-    connect(d->mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(selectionChanged()));
-    connect(d->mModel, SIGNAL(dndDone()), SLOT(dndDone()));
-    connect(d->mModel, SIGNAL(addNewDndSnippset(QString)), this, SLOT(slotAddNewDndSnippset(QString)));
+    connect(d->mSelectionModel, &QItemSelectionModel::selectionChanged,
+            this, [this]() {
+        d->selectionChanged();
+    });
+    connect(d->mModel, &SnippetsModel::dndDone, this, [this]() {
+        d->dndDone();
+    });
+    connect(d->mModel, &SnippetsModel::addNewDndSnippset, this, [this](const QString &str) {
+        d->slotAddNewDndSnippset(str);
+    });
 
-    connect(d->mAddSnippetAction, SIGNAL(triggered(bool)), SLOT(addSnippet()));
-    connect(d->mEditSnippetAction, SIGNAL(triggered(bool)), SLOT(editSnippet()));
-    connect(d->mDeleteSnippetAction, SIGNAL(triggered(bool)), SLOT(deleteSnippet()));
+    connect(d->mAddSnippetAction, &QAction::triggered, this, [this]() {
+        d->addSnippet();
+    });
+    connect(d->mEditSnippetAction, &QAction::triggered, this, [this]() {
+        d->editSnippet();
+    });
+    connect(d->mDeleteSnippetAction, &QAction::triggered, this, [this]() {
+        d->deleteSnippet();
+    });
 
-    connect(d->mAddSnippetGroupAction, SIGNAL(triggered(bool)), SLOT(addSnippetGroup()));
-    connect(d->mEditSnippetGroupAction, SIGNAL(triggered(bool)), SLOT(editSnippetGroup()));
-    connect(d->mDeleteSnippetGroupAction, SIGNAL(triggered(bool)), SLOT(deleteSnippetGroup()));
+    connect(d->mAddSnippetGroupAction, &QAction::triggered, this, [this]() {
+        d->addSnippetGroup();
+    });
+    connect(d->mEditSnippetGroupAction, &QAction::triggered, this, [this]() {
+        d->editSnippetGroup();
+    });
+    connect(d->mDeleteSnippetGroupAction, &QAction::triggered, this, [this]() {
+        d->deleteSnippetGroup();
+    });
 
-    connect(d->mInsertSnippetAction, SIGNAL(triggered(bool)), SLOT(insertSelectedSnippet()));
+    connect(d->mInsertSnippetAction, &QAction::triggered, this, [this]() {
+        d->insertSelectedSnippet();
+    });
 
     d->selectionChanged();
 
@@ -641,7 +669,7 @@ void SnippetsManager::setEditor(QObject *editor, const char *insertSnippetMethod
     if (dropSignal) {
         const int index
             = editor->metaObject()->indexOfSignal(
-            QMetaObject::normalizedSignature(dropSignal + 1).data());        // skip the leading '2'
+                  QMetaObject::normalizedSignature(dropSignal + 1).data());  // skip the leading '2'
         if (index != -1) {
             connect(editor, dropSignal, this, SLOT(insertSelectedSnippet()));
         }
